cl<-read.dta("clusters.dta")
wom<-read.dta("women.dta")


#====================calculating distance to water of each cluster
# The DistancePointToClass function 
# first creates a raster called rasterPointXY in which only the
# point of interest is given a value (1).
# Then it uses the gridDistance() function to 
# find the distance
# from this cell to all others on the same raster,
# producing a new raster where the value of each cell
# is its distance from this point. Finally it 
# finds the cell with the minimum distance value where the
# cell also represents the focal class of the input classRaster.

DistancePointToClass <- function(classRaster, pointXY,focalClass) {
rasterPointXY <- classRaster
rasterPointXY[] <- NA
rasterPointXY[cellFromXY(classRaster, pointXY)] <- 1
distanceFrom <- gridDistance(rasterPointXY, origin = 1)
minDistance <- min(distanceFrom[classRaster[] ==focalClass])
return(minDistance)
}

# building water data from NA in density grids
water_af <- raster('grump\\afuds90ag.asc',native=TRUE)
water_as <- raster('grump\\asuds90ag.asc',native=TRUE)
water_na <- raster('grump\\nauds90ag.asc',native=TRUE)
water_sa <- raster('grump\\sauds90ag.asc',native=TRUE)

water_gl=merge(water_af,water_as,water_na,water_sa)

water_af0 <- crop(water_gl,  extent(-19, 53, -36, 38))
water_as1 <- crop(water_gl,  extent(34, 93, 20, 38))
water_as2 <- crop(water_gl,  extent(11, 141, -11, 21))
water_na0 <- crop(water_gl,  extent(-93, -82, 6, 17))
water_sa0 <- crop(water_gl,  extent(-82, -57, -24, 14))

water_af0[!is.na(water_af0)] <- 1 
water_as1[!is.na(water_as1)] <- 1 
water_as2[!is.na(water_as2)] <- 1 
water_na0[!is.na(water_na0)] <- 1 
water_sa0[!is.na(water_sa0)] <- 1

water_af0[is.na(water_af0)] <- 2 
water_as1[is.na(water_as1)] <- 2 
water_as2[is.na(water_as2)] <- 2 
water_na0[is.na(water_na0)] <- 2 
water_sa0[is.na(water_sa0)] <- 2 

water_as0=merge(water_as1,water_as2)

# here we aggregate points to speed up the next process of calculating min distances to water
# fact=10: implies we go from a definition of 30 seconds to 5 minutes
# Aggregation of a Raster* object will result in a Raster* object with fact*fact fewer cells
 
water_af0 <- aggregate(water_af0, fact=10, fun=min)
water_as0 <- aggregate(water_as0, fact=10, fun=min)
water_na0 <- aggregate(water_na0, fact=10, fun=min)
water_sa0 <- aggregate(water_sa0, fact=10, fun=min)

#some pictures

#pdf(file="pict\\map-water.pdf",width=10, height=5)
#plot(merge(water_af0,water_as0,water_na0,water_sa0))
#dev.off()

#============================== we now compute distance to water

cl$dist_water[cl$continent==1 | cl$MA==1 | cl$EG==1] <- 0
 for (i in 1:nrow(cl[cl$continent==1 | cl$MA==1 | cl$EG==1,])) {
cat("Point", i, "of", nrow(cl[cl$continent==1 | cl$MA==1 | cl$EG==1,]), "\n")
cl$dist_water[cl$continent==1 | cl$MA==1 | cl$EG==1][i] <- DistancePointToClass(water_af0,c(cl$x[cl$continent==1 | cl$MA==1 | cl$EG==1][i],
 cl$y[cl$continent==1 | cl$MA==1 | cl$EG==1][i]), 2)
}

cl$dist_water[cl$continent==3 | cl$JO==1] <- 0
 for (i in 1:nrow(cl[cl$continent==3 | cl$JO==1,])) {
cat("Point", i, "of", nrow(cl[cl$continent==3 | cl$JO==1,]), "\n")
cl$dist_water[cl$continent==3 | cl$JO==1][i] <- DistancePointToClass(water_as0,c(cl$x[cl$continent==3 | cl$JO==1][i],
 cl$y[cl$continent==3 | cl$JO==1][i]), 2)
}

cl$dist_water[cl$HN==1] <- 0
 for (i in 1:nrow(cl[cl$HN==1,])) {
cat("Point", i, "of", nrow(cl[cl$HN==1,]), "\n")
cl$dist_water[cl$HN==1][i] <- DistancePointToClass(water_na0,c(cl$x[cl$HN==1][i],
 cl$y[cl$HN==1][i]), 2)
}

cl$dist_water[cl$BO==1 | cl$CO==1  | cl$PE==1] <- 0
 for (i in 1:nrow(cl[cl$BO==1 | cl$CO==1  | cl$PE==1,])) {
cat("Point", i, "of", nrow(cl[cl$BO==1 | cl$CO==1  | cl$PE==1,]), "\n")
cl$dist_water[scl$BO==1 | cl$CO==1  | cl$PE==1][i] <- DistancePointToClass(water_sa0,c(cl$x[cl$BO==1 | cl$CO==1  | cl$PE==1][i],
 cl$y[cl$BO==1 | cl$CO==1  | cl$PE==1][i]), 2)
}

#transforms meters into degrees
cl$dist_water <- cl$dist_water/111120



listc <- unique(cl$id)

for (i in listc) {
wom[wom$cluster==i,"dist_water"] <- cl$dist_water[cl$id==i]
}


write.dta(cl,"clusters.dta")
write.dta(wom,"women.dta")